/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.cropfield.type;

import java.awt.BorderLayout;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import nl.cloudfarming.client.farm.model.CropField;
import nl.cloudfarming.client.geoviewer.render.GeometricalPreviewPanel;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

/**
 * Visual tab for CropFields
 * @author Gerben Feenstra
 */
@MultiViewElement.Registration(displayName = "#LBL_CropField_VISUAL",
iconBase = "nl/cloudfarming/client/cropfield/type/cropfield.png",
mimeType = CropField.MIMETYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "CropFieldVisual",
position = 2000)
@Messages(value={"LBL_CropField_VISUAL=Visual","Title_CropField_VISUAL=Crop field visual preview"})
public final class CropFieldVisualElement extends JPanel implements MultiViewElement, HelpCtx.Provider {

    private CropFieldDataObject cropFieldDataObject;
    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;

    public CropFieldVisualElement(Lookup lkp) {
        this.cropFieldDataObject = lkp.lookup(CropFieldDataObject.class);
        CropField cropField = lkp.lookup(CropField.class);
        assert cropFieldDataObject != null:" lookup should contain a CropFieldDataObject";
        assert cropField != null:" lookup should contain a CropField Object";
        
        this.setLayout(new BorderLayout());
        ASBodyPanel contentPanel = new ASBodyPanel(new GeometricalPreviewPanel(cropField));
        contentPanel.setTitle(Bundle.Title_CropField_VISUAL());
        //FIXME add image icon, cropfield32.png missing
        add(contentPanel);
    }

    @Override
    public String getName() {
        return "CropFieldVisualElement";
    }

    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return cropFieldDataObject.getLookup();
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            CropField cropField = cropFieldDataObject.getLookup().lookup(CropField.class);
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(cropField.getName());
            tc.setDisplayName(cropField.getName());
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }
    
    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.cropfield.type.about");
    } 
}
